@@ -50,7 +50,7 @@ public:
     /**
       Creates a new ResourceScanJob.
     */
-    explicit ResourceScanJob(const QString &resourceId, KCoreConfigSkeleton *settings, QObject *parent = 0);
+    explicit ResourceScanJob(const QString &resourceId, KCoreConfigSkeleton *settings, QObject *parent = nullptr);
 
     /**
       Destroys this ResourceScanJob.
@@ -82,7 +82,7 @@ public:
 
 protected:
     /* reimpl */
-    void doStart() Q_DECL_OVERRIDE;
+    void doStart() override;
 
 private:
     class Private;
@@ -121,7 +121,7 @@ public:
     /**
      * Creates a new DefaultResourceJob.
      */
-    explicit DefaultResourceJob(KCoreConfigSkeleton *settings, QObject *parent = 0);
+    explicit DefaultResourceJob(KCoreConfigSkeleton *settings, QObject *parent = nullptr);
 
     /**
      * Destroys the DefaultResourceJob.
@@ -157,9 +157,9 @@ public:
 
 protected:
     /* reimpl */
-    void doStart() Q_DECL_OVERRIDE;
+    void doStart() override;
     /* reimpl */
-    void slotResult(KJob *job) Q_DECL_OVERRIDE;
+    void slotResult(KJob *job) override;
 
 private:
     friend class DefaultResourceJobPrivate;
@@ -199,7 +199,7 @@ public:
     /**
       Creates a new GetLockJob.
     */
-    explicit GetLockJob(QObject *parent = 0);
+    explicit GetLockJob(QObject *parent = nullptr);
 
     /**
       Destroys the GetLockJob.
@@ -207,7 +207,7 @@ public:
     ~GetLockJob();
 
     /* reimpl */
-    void start() Q_DECL_OVERRIDE;
+    void start() override;
 
 private:
     class Private;
