@@ -1,6 +1,6 @@
 /*
     Copyright (c) 2009 Stephen Kelly <steveire@gmail.com>
-    Copyright (c) 2012 Laurent Montel <montel@kde.org>
+    Copyright (C) 2012-2017 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -46,7 +46,7 @@ public:
      *
      * @param parent The parent object.
      */
-    explicit RecursiveCollectionFilterProxyModel(QObject *parent = Q_NULLPTR);
+    explicit RecursiveCollectionFilterProxyModel(QObject *parent = nullptr);
 
     /**
      * Destroys the recursive collection filter proxy model.
@@ -99,8 +99,8 @@ public:
     void setIncludeCheckedOnly(bool checked);
 
 protected:
-    bool acceptRow(int sourceRow, const QModelIndex &sourceParent) const Q_DECL_OVERRIDE;
-    int columnCount(const QModelIndex &index) const Q_DECL_OVERRIDE;
+    bool acceptRow(int sourceRow, const QModelIndex &sourceParent) const override;
+    int columnCount(const QModelIndex &index) const override;
 
 protected:
     RecursiveCollectionFilterProxyModelPrivate *const d_ptr;
