@@ -18,7 +18,7 @@
 */
 
 #include "move.h"
-#include "helper_p.h"
+
 #include "connection.h"
 #include "handlerhelper.h"
 #include "cachecleaner.h"
@@ -41,7 +41,7 @@ void Move::itemsRetrieved(const QList<qint64> &ids)
     ItemQueryHelper::itemSetToQuery(ImapSet(ids), qb);
     qb.addValueCondition(PimItem::collectionIdFullColumnName(), Query::NotEquals, mDestination.id());
 
-    const QDateTime mtime = QDateTime::currentDateTime();
+    const QDateTime mtime = QDateTime::currentDateTimeUtc();
 
     if (!qb.exec()) {
         failureResponse("Unable to execute query");
@@ -129,7 +129,7 @@ void Move::itemsRetrieved(const QList<qint64> &ids)
 
 bool Move::parseStream()
 {
-    Protocol::MoveItemsCommand cmd(m_command);
+    const auto &cmd = Protocol::cmdCast<Protocol::MoveItemsCommand>(m_command);
 
     mDestination = HandlerHelper::collectionFromScope(cmd.destination(), connection());
     if (mDestination.isVirtual()) {
