@@ -23,8 +23,7 @@
 #include "itemmodel.h"
 
 #include <KXMLGUIFactory>
-#include <KXmlGuiWindow>
-
+#include <KXMLGUIClient>
 #include <QContextMenuEvent>
 #include <QHeaderView>
 #include <QMenu>
@@ -51,10 +50,10 @@ public:
 
     Item itemForIndex(const QModelIndex &index);
 
-    KXMLGUIClient *xmlGuiClient;
+    KXMLGUIClient *xmlGuiClient = nullptr;
 
 private:
-    ItemView *mParent;
+    ItemView *mParent = nullptr;
 };
 
 void ItemView::Private::init()
